@@ -47,8 +47,8 @@ Class declaration
 Base = declarative_base()
 
 
-class Observation(Base):
-    __tablename__ = 'observations'
+class DB_observation(Base):
+    __tablename__ = 'DB_observations'
 
     id = Column(String)
     observation_id = Column(String, primary_key=True)
@@ -103,7 +103,7 @@ class Kraken_db:
 
 
     """
-    API - observations
+    API - DB_observations
     """
 
 
@@ -117,14 +117,14 @@ class Kraken_db:
 
 
     def get(self, record_type = None, record_id = None, key = None, value = None):
-        # Get observations matching conditions
+        # Get DB_observations matching conditions
         query = self._get_observations(record_type, record_id, key, value)
 
         return self._to_dict(query)
 
 
     def get_max(self, record_type = None, record_id = None, key = None, value = None):
-        """Return max observation
+        """Return max DB_observation
         """
         query = self._get_max_observations(record_type, record_id, key, value)
 
@@ -133,7 +133,7 @@ class Kraken_db:
 
 
     def get_summary(self, record_type = None, record_id = None, key = None, value = None):
-        """Return object with max observation for each key
+        """Return object with max DB_observation for each key
         """
 
         query = self._get_summary(record_type, record_id, key, value)
@@ -142,7 +142,7 @@ class Kraken_db:
 
 
     def get_summary_by_value(self, record_type = None, record_id = None):
-        """Return object with max observation for each key value combination
+        """Return object with max DB_observation for each key value combination
         """
 
         query = self._get_summaries_by_value(record_type, record_id)
@@ -185,7 +185,7 @@ class Kraken_db:
 
 
     def post(self, record):
-        """Post an observation. Need ot be committed
+        """Post an DB_observation. Need ot be committed
         """
         result = self._post_observation_from_record(record)
         result = self.commit()
@@ -205,7 +205,7 @@ class Kraken_db:
 
 
     def commit(self):
-        """Commmit posting of observations
+        """Commmit posting of DB_observations
         """
         self._commit()
 
@@ -218,7 +218,7 @@ class Kraken_db:
     def list_record_types(self):
         """Return list of dict with record_types and number for each
         """
-        query = self.session.query(func.count(distinct(Observation.record_id)), Observation.record_type).group_by(Observation.record_type).all()
+        query = self.session.query(func.count(distinct(DB_observation.record_id)), DB_observation.record_type).group_by(DB_observation.record_type).all()
 
         records = []
         for n, t in query:
@@ -233,21 +233,21 @@ class Kraken_db:
 
 
     def _get_observations(self, record_type, record_id, key, value):
-        """ Return observations matching condition
+        """ Return DB_observations matching condition
         """
-        query = self.session.query(Observation)
+        query = self.session.query(DB_observation)
 
         if record_type:
-            query = query.filter(Observation.record_type == record_type)
+            query = query.filter(DB_observation.record_type == record_type)
 
         if record_id:
-            query = query.filter(Observation.record_id == record_id)
+            query = query.filter(DB_observation.record_id == record_id)
             
         if key:
-            query = query.filter(Observation.key == key)
+            query = query.filter(DB_observation.key == key)
 
         if value:
-            query = query.filter(Observation.value == value)
+            query = query.filter(DB_observation.value == value)
 
 
         return query
@@ -258,7 +258,7 @@ class Kraken_db:
 
         query = self._get_observations(record_type, record_id, key, value)
 
-        query.order_by(Observation.credibility.desc()).order_by(Observation.credibility.created_date())
+        query.order_by(DB_observation.credibility.desc()).order_by(DB_observation.credibility.created_date())
 
         # Limit
         query = query.limit(1)
@@ -275,7 +275,7 @@ class Kraken_db:
         return query
 
     def _get_summaries(self, query):
-        """Returns best observation for each keys of records in scope of query
+        """Returns best DB_observation for each keys of records in scope of query
         """
 
         subquery1 = query
@@ -301,11 +301,11 @@ class Kraken_db:
 
 
     def _get_summaries_by_value(self, record_type, record_id):
-        """Returns best observation for each keys/values of records in scope of query
+        """Returns best DB_observation for each keys/values of records in scope of query
         """
 
         # Get max cred for each key
-        obs1 = aliased(Observation)
+        obs1 = aliased(DB_observation)
 
         subquery1 = self.session.query(obs1)
         subquery1 = subquery1.filter(obs1.record_type == record_type)
@@ -348,7 +348,7 @@ class Kraken_db:
 
         record_ref_id = str(record.get('record_type', None)) + '/' + str(record.get('record_id', None))
 
-        obs = Observation(
+        obs = DB_observation(
             observation_id = record.get('observation_id', None),
             ref_id = record_ref_id,
             datasource = record.get('datasource', None),
@@ -390,14 +390,14 @@ class Kraken_db:
     def _update(self, old_record_type, old_record_id, new_record_type, new_record_id):
 
         # Step 1. Update record_ids
-        query = self.session.query(Observation)
-        query = query.filter(Observation.record_type == old_record_type)
-        query = query.filter(Observation.record_id == old_record_id)
+        query = self.session.query(DB_observation)
+        query = query.filter(DB_observation.record_type == old_record_type)
+        query = query.filter(DB_observation.record_id == old_record_id)
 
         query = query.update(
             {
-                Observation.record_type: new_record_type, 
-                Observation.record_id: new_record_id
+                DB_observation.record_type: new_record_type, 
+                DB_observation.record_id: new_record_id
                 })
 
 
@@ -414,12 +414,12 @@ class Kraken_db:
         }
         new_record = json.dumps(new_record, default=str)
 
-        query = self.session.query(Observation)
-        query = query.filter(Observation.value == old_record)
+        query = self.session.query(DB_observation)
+        query = query.filter(DB_observation.value == old_record)
 
         query = query.update(
             {
-                Observation.value: new_record }
+                DB_observation.value: new_record }
                 )
 
 
@@ -435,10 +435,10 @@ class Kraken_db:
 
         query = None
 
-        obs0 = aliased(Observation)
+        obs0 = aliased(DB_observation)
 
 
-        # Step 1. Find observations meeting conditions
+        # Step 1. Find DB_observations meeting conditions
         for key, operator, value in params:
             sub_query = self.session.query(obs0.ref_id, obs0.record_id)
 
@@ -548,10 +548,10 @@ class Kraken_db:
 
 
 
-        # Step 2. Retrieve all observations with same ref_id
-        #obs1 = aliased(Observation)
-        subquery1 = self.session.query(Observation)
-        subquery1 = subquery1.join(query, query.c.ref_id == Observation.ref_id)
+        # Step 2. Retrieve all DB_observations with same ref_id
+        #obs1 = aliased(DB_observation)
+        subquery1 = self.session.query(DB_observation)
+        subquery1 = subquery1.join(query, query.c.ref_id == DB_observation.ref_id)
 
 
         
